@@ -43,19 +43,19 @@ class Exceptions:
 
 class MediaTailorClient:
     """
-    [MediaTailor.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client)
+    [MediaTailor.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         """
 
     def delete_playback_configuration(self, Name: str) -> Dict[str, Any]:
         """
-        [Client.delete_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Client.delete_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         """
 
     def generate_presigned_url(
@@ -66,33 +66,33 @@ class MediaTailorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         """
 
     def get_playback_configuration(self, Name: str) -> GetPlaybackConfigurationResponseTypeDef:
         """
-        [Client.get_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Client.get_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         """
 
     def list_playback_configurations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListPlaybackConfigurationsResponseTypeDef:
         """
-        [Client.list_playback_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        [Client.list_playback_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         """
 
     def put_playback_configuration(
         self,
         AdDecisionServerUrl: str = None,
-        AvailSuppression: AvailSuppressionTypeDef = None,
-        CdnConfiguration: CdnConfigurationTypeDef = None,
+        AvailSuppression: "AvailSuppressionTypeDef" = None,
+        CdnConfiguration: "CdnConfigurationTypeDef" = None,
         DashConfiguration: DashConfigurationForPutTypeDef = None,
-        LivePreRollConfiguration: LivePreRollConfigurationTypeDef = None,
+        LivePreRollConfiguration: "LivePreRollConfigurationTypeDef" = None,
         Name: str = None,
         PersonalizationThresholdSeconds: int = None,
         SlateAdUrl: str = None,
@@ -101,17 +101,17 @@ class MediaTailorClient:
         VideoContentSourceUrl: str = None,
     ) -> PutPlaybackConfigurationResponseTypeDef:
         """
-        [Client.put_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Client.put_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         """
 
     @overload
@@ -119,5 +119,5 @@ class MediaTailorClient:
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+        [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
         """
