@@ -23,12 +23,12 @@ else:
 __all__ = (
     "AvailSuppressionTypeDef",
     "CdnConfigurationTypeDef",
-    "DashConfigurationForPutTypeDef",
     "DashConfigurationTypeDef",
     "HlsConfigurationTypeDef",
     "LivePreRollConfigurationTypeDef",
-    "GetPlaybackConfigurationResponseTypeDef",
     "PlaybackConfigurationTypeDef",
+    "DashConfigurationForPutTypeDef",
+    "GetPlaybackConfigurationResponseTypeDef",
     "ListPlaybackConfigurationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -47,12 +47,6 @@ CdnConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-DashConfigurationForPutTypeDef = TypedDict(
-    "DashConfigurationForPutTypeDef",
-    {"MpdLocation": str, "OriginManifestType": Literal["SINGLE_PERIOD", "MULTI_PERIOD"]},
-    total=False,
-)
-
 DashConfigurationTypeDef = TypedDict(
     "DashConfigurationTypeDef",
     {
@@ -73,44 +67,50 @@ LivePreRollConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-GetPlaybackConfigurationResponseTypeDef = TypedDict(
-    "GetPlaybackConfigurationResponseTypeDef",
+PlaybackConfigurationTypeDef = TypedDict(
+    "PlaybackConfigurationTypeDef",
     {
         "AdDecisionServerUrl": str,
-        "AvailSuppression": AvailSuppressionTypeDef,
-        "CdnConfiguration": CdnConfigurationTypeDef,
-        "DashConfiguration": DashConfigurationTypeDef,
-        "HlsConfiguration": HlsConfigurationTypeDef,
-        "LivePreRollConfiguration": LivePreRollConfigurationTypeDef,
+        "AvailSuppression": "AvailSuppressionTypeDef",
+        "CdnConfiguration": "CdnConfigurationTypeDef",
+        "DashConfiguration": "DashConfigurationTypeDef",
+        "HlsConfiguration": "HlsConfigurationTypeDef",
         "Name": str,
-        "PersonalizationThresholdSeconds": int,
         "PlaybackConfigurationArn": str,
         "PlaybackEndpointPrefix": str,
         "SessionInitializationEndpointPrefix": str,
         "SlateAdUrl": str,
         "Tags": Dict[str, str],
         "TranscodeProfileName": str,
+        "PersonalizationThresholdSeconds": int,
         "VideoContentSourceUrl": str,
     },
     total=False,
 )
 
-PlaybackConfigurationTypeDef = TypedDict(
-    "PlaybackConfigurationTypeDef",
+DashConfigurationForPutTypeDef = TypedDict(
+    "DashConfigurationForPutTypeDef",
+    {"MpdLocation": str, "OriginManifestType": Literal["SINGLE_PERIOD", "MULTI_PERIOD"]},
+    total=False,
+)
+
+GetPlaybackConfigurationResponseTypeDef = TypedDict(
+    "GetPlaybackConfigurationResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
-        "AvailSuppression": AvailSuppressionTypeDef,
-        "CdnConfiguration": CdnConfigurationTypeDef,
-        "DashConfiguration": DashConfigurationTypeDef,
-        "HlsConfiguration": HlsConfigurationTypeDef,
+        "AvailSuppression": "AvailSuppressionTypeDef",
+        "CdnConfiguration": "CdnConfigurationTypeDef",
+        "DashConfiguration": "DashConfigurationTypeDef",
+        "HlsConfiguration": "HlsConfigurationTypeDef",
+        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
         "Name": str,
+        "PersonalizationThresholdSeconds": int,
         "PlaybackConfigurationArn": str,
         "PlaybackEndpointPrefix": str,
         "SessionInitializationEndpointPrefix": str,
         "SlateAdUrl": str,
         "Tags": Dict[str, str],
         "TranscodeProfileName": str,
-        "PersonalizationThresholdSeconds": int,
         "VideoContentSourceUrl": str,
     },
     total=False,
@@ -118,7 +118,7 @@ PlaybackConfigurationTypeDef = TypedDict(
 
 ListPlaybackConfigurationsResponseTypeDef = TypedDict(
     "ListPlaybackConfigurationsResponseTypeDef",
-    {"Items": List[PlaybackConfigurationTypeDef], "NextToken": str},
+    {"Items": List["PlaybackConfigurationTypeDef"], "NextToken": str},
     total=False,
 )
 
@@ -134,11 +134,11 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
     "PutPlaybackConfigurationResponseTypeDef",
     {
         "AdDecisionServerUrl": str,
-        "AvailSuppression": AvailSuppressionTypeDef,
-        "CdnConfiguration": CdnConfigurationTypeDef,
-        "DashConfiguration": DashConfigurationTypeDef,
-        "HlsConfiguration": HlsConfigurationTypeDef,
-        "LivePreRollConfiguration": LivePreRollConfigurationTypeDef,
+        "AvailSuppression": "AvailSuppressionTypeDef",
+        "CdnConfiguration": "CdnConfigurationTypeDef",
+        "DashConfiguration": "DashConfigurationTypeDef",
+        "HlsConfiguration": "HlsConfigurationTypeDef",
+        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
         "PlaybackConfigurationArn": str,
